﻿using MindFusion.Charting;

namespace Tutorial2
{
	enum PriceType
	{
		Open,
		Close,
		Low,
		High
	};

	class MySeries : Series
	{
		/// <summary>
		/// All MySeries instances displayed by the chart contain a reference
		/// to same list of StockPrice objects, so we can avoid copying data.
		/// </summary>
		public List<StockPrice> Prices { get; set; }

		/// <summary>
		/// Indicates which of the StockPrice members is returned as data value.
		/// </summary>
		public PriceType PriceType { get; set; }

		/// <summary>
		/// The only constructor we allow must receive a reference to StockPrice list.
		/// </summary>
		public MySeries(List<StockPrice> prices, PriceType priceType)
		{
			Prices = prices;
			PriceType = priceType;
		}

		/// <summary>
		/// This lets the chart know how many data points it should draw.
		/// </summary>
		public int Size => Prices.Count;

		/// <summary>
		/// For the BarChart in this example, we only return one-dimensional data (Y values).
		/// </summary>
		public int Dimensions => 1;

		/// <summary>
		/// Returns the data value by reading specified StockPrice member.
		/// </summary>
		public double GetValue(int index, int dimension)
		{
			switch (PriceType)
			{
				case PriceType.Open:
					return Prices[index].Open;
				case PriceType.Close:
					return Prices[index].Close;
				case PriceType.Low:
					return Prices[index].Low;
				case PriceType.High:
					return Prices[index].High;
			}
			return 0;
		}

		/// <summary>
		/// We only show date string on the X axis for one of the series.
		/// </summary>
		public LabelKinds SupportedLabels =>
			PriceType == PriceType.Open ? LabelKinds.XAxisLabel : LabelKinds.None;

		/// <summary>
		/// Can return data labels to draw inside or above bars, at either axis, or as tooltips.
		/// </summary>
		public string GetLabel(int index, LabelKinds kind)
		{
			return Prices[index].Date.ToShortDateString();
		}

		/// <summary>
		/// Title strings are displayed inside the legend box.
		/// </summary>
		public string Title => PriceType.ToString();

		/// <summary>
		/// The chart refreshes automatically if this event is raised (not used in this example).
		/// </summary>
		public event EventHandler DataChanged;

		/// <summary>
		/// The charts draw respective data element as highlighted if this returns true.
		/// </summary>
		public bool IsEmphasized(int index)
		{
			return false;
		}

		/// <summary>
		/// The chart can do some optimizations, such as binary search for viewport
		/// clipping, if it knows data values are returned sorted.
		/// Return true if data is actually sorted, or you will get incorrect results.
		/// </summary>
		public bool IsSorted(int dimension)
		{
			return false;
		}
	};
}
